@@ -4,5 +4,5 @@ export PIP_NO_INDEX=False
 export PIP_NO_DEPENDENCIES=False
 export PIP_IGNORE_INSTALLED=False
 
-$PYTHON -m pip install pysoundfile -vv
+# $PYTHON -m pip install pysoundfile -vv
 $PYTHON -m pip install xarray-behave[gui] -vv --no-dependencies
