@@ -131,7 +131,7 @@ class Events(UserDict):
         new_row = pd.DataFrame(np.array([name, start_seconds,
                                          stop_seconds])[np.newaxis, :],
                                columns=df.columns)
-        return df.append(new_row, ignore_index=True)
+        return pd.concat((df, new_row), ignore_index=True)
 
     def to_df(self, preserve_empty: bool = True):
         """Convert to pandas.DataFeame
@@ -460,7 +460,7 @@ class Events(UserDict):
         """
         indices = self.select_range(name, t0, t1, strict)
         self[name] = np.delete(self[name], indices, axis=0)
-        return len(indices)
+        return indices
 
     def find_next(self, t: float, names: Optional[List[str]] = None):
         """Find event starting after `t` of type in names.
