@@ -15,8 +15,6 @@ from typing import Tuple
 
 from .. import xarray_behave as xb
 from . import utils
-from . import formbuilder
-from . import app
 
 
 logger = logging.getLogger(__name__)
@@ -283,11 +281,7 @@ class TraceView(pg.PlotWidget):
     def add_event(self, xx, event_type, pen, movable=False, text=None):
         if not len(xx):
             return
-        # if not movable:
-        #     xx = np.broadcast_to(xx[np.newaxis, :], (2, len(xx)))
-        #     yy = np.zeros_like(xx) + self.yrange[:, np.newaxis]
-        #     utils.fast_plot(self, xx.T, yy.T, pen)
-        # else:
+
         for x in xx:
             line = EventItem(x, event_type, self.xrange, movable=True, angle=90, pen=pen)
             if text is not None:
@@ -328,7 +322,7 @@ class TrackView(TraceView):
 
 class SpecView(pg.ImageView):
 
-    def __init__(self, model, callback, colormap=None):
+    def __init__(self, model, callback, colormap='turbo'):
         super().__init__(view=pg.PlotItem())
         self.ui.histogram.hide()
         self.ui.roiBtn.hide()
@@ -347,12 +341,16 @@ class SpecView(pg.ImageView):
         self._m = model
         self.callback = callback
         self.imageItem.mouseClickEvent = self._click
+        self.t_step = 1
+        self.max_pix = 6_000
 
         self.pos_line = pg.InfiniteLine(pos=0.5, movable=False, angle=90,
                                         pen=pg.mkPen(color='r', width=1))
         self.addItem(self.pos_line)
-        if colormap is not None:
-            self.imageItem.setLookupTable(colormap)  # apply the colormap
+
+        cmap = pg.colormap.getFromMatplotlib(colormap)
+        lut = cmap.getLookupTable()
+        self.imageItem.setLookupTable(lut)  # apply the colormap
         self.old_items = []
 
     @property
@@ -377,55 +375,42 @@ class SpecView(pg.ImageView):
         [self.removeItem(item) for item in self.old_items]  # remove annotations <- slowest part of update_spec!!!
 
     def update_spec(self, x, y):
-        # hash x to avoid re-calculation? only useful when annotating
-        # t0 = time.time()
-        # t1 = time.time()
-        # logger.debug(f'  update spec - clear annotations: {t1-t0}')
-
-        # S, f, t = self._calc_spec(y)
-        S, f, t = self._calc_spec(tuple(y), self.m.spec_win)  # tuple-ify for caching
-        self.S = S
+        self.S, f, t = self._calc_spec(tuple(y), self.m.spec_win, self.m.spec_compression_ratio)  # tuple-ify for caching
         trange = (self.m.x[-1] - self.m.x[0])
-        # t2 = time.time()
-        # logger.debug(f'  update spec - calc spec: {t2-t0}')
-
-        self.setImage(S.T, autoRange=False, scale=[trange / len(t), (f[-1] - f[0]) / len(f)], pos=[self.m.x[0], f[0]])
+        self.max_pix = 6_000
+        self.t_step = max(1, self.S.shape[1] // self.max_pix)
+        self.setImage(self.S.T[::self.t_step], autoRange=False, scale=[trange / len(t) * self.t_step, (f[-1] - f[0]) / len(f)], pos=[self.m.x[0], f[0]])
         self.view.setRange(xRange=self.m.x[[0, -1]], yRange=(f[0], f[-1]), padding=0)
-
         self.pos_line.setValue(self.m.x[int(self.m.span / 2)])
 
-        # t3 = time.time()
-        # logger.debug(f'  update spec - draw: {t3-t2}')
-        # t4 = time.time()
-        # logger.debug(f'update spec - TOTAL: {t4-t0}')
-
-    @lru_cache(maxsize=2, typed=False)
-    def _calc_spec(self, y, spec_win):
+    @lru_cache(maxsize=4, typed=False)
+    def _calc_spec(self, y, spec_win, spec_compression_ratio):
         y = np.array(y)
         # signal.spectrogram will internally limit spec_win to len(y)
         # and will throw error since noverlap will then be too big
         spec_win = min(len(y), spec_win)
+
+        # ranges between 1 and 4 times spec_win - smaller when zoomed out
+        # to accelerate calc
+        nfft = spec_win * max(1, 4 // self.t_step)
+
         f, t, psd = scipy.signal.spectrogram(y, self.m.fs_song, nperseg=spec_win,
-                                             noverlap=spec_win // 2, nfft=spec_win * 4, mode='magnitude')
-        self.spec_t = t
-
-        if self.m.fmax is not None:
-            f_idx1 = len(f) - 1 - np.argmax(f[::-1] <= self.m.fmax)
-        else:
-            f_idx1 = -1
+                                             noverlap=spec_win // 2, nfft=nfft, mode='magnitude')
 
+        # select freq limits
+        f_idx0 = 0
         if self.m.fmin is not None:
             f_idx0 = np.argmax(f >= self.m.fmin)
-        else:
-            f_idx0 = 0
+        f_idx1 = -1
+        if self.m.fmax is not None:
+            f_idx1 = len(f) - 1 - np.argmax(f[::-1] <= self.m.fmax)
 
-        S = np.log2(1 + psd[f_idx0:f_idx1, :])
+        S = np.log2(1 + 2**spec_compression_ratio * psd[f_idx0:f_idx1, :])
         S = S / np.max(S) * 255  # normalize to 0...255
         return S, f[f_idx0:f_idx1], t
 
     def add_segment(self, onset, offset, region_typeindex, brush=None, pen=None, movable=True, text=None):
-        onset_spec, offset_spec = onset, offset
-        region = SegmentItem((onset_spec, offset_spec), region_typeindex, self.xrange,
+        region = SegmentItem((onset, offset), region_typeindex, self.xrange,
                              time_bounds=(onset, offset), brush=brush, pen=pen, movable=movable)
         if text is not None:
             pg.InfLineLabel(region.lines[1], text, position=0.95, rotateAxis=(1,0), anchor=(1, 1))
@@ -438,15 +423,9 @@ class SpecView(pg.ImageView):
     def add_event(self, xx, event_type, pen, movable=False, text=None):
         if not len(xx):
             return
-        xx0 = xx.copy()
-        # xx = self.time_to_pos(xx)
-        # if not movable:
-        #     xx = np.broadcast_to(xx[np.newaxis, :], (2, len(xx)))
-        #     yy = np.zeros_like(xx) + self.yrange[:, np.newaxis]
-        #     self.old_items.append(utils.fast_plot(self, xx.T, yy.T, pen))
-        # else:
-        for (x, x0) in zip(xx, xx0):
-            line = EventItem(x, event_type, self.xrange, time_pos=x0, movable=True, angle=90, pen=pen)
+
+        for x in xx:
+            line = EventItem(x, event_type, self.xrange, time_pos=x, movable=True, angle=90, pen=pen)
             if text is not None:
                 pg.InfLineLabel(line, text, position=0.95, rotateAxis=(1,0), anchor=(1, 1))
             line.sigPositionChangeFinished.connect(self.m.on_position_change_finished)
@@ -462,7 +441,7 @@ class SpecView(pg.ImageView):
     def _click(self, event):
         event.accept()
         pos = event.pos()[0]
-        mouseT = self.pos_to_time(pos)
+        mouseT = self.pos_to_time(pos) * self.t_step
         self.callback(mouseT, event.button())
 
 
@@ -542,9 +521,9 @@ class MovieView(utils.FastImageWidget):
                 if self.m.crop:
                     x_range, y_range = self.crop_frame(frame)
                 else:
-                    x_range, y_range = [0, self.m.vr.frame_width], [0, self.m.vr.frame_height]
+                    x_range, y_range = [0, self.m.vr.frame_height], [0, self.m.vr.frame_width]
             else:
-                x_range, y_range = [0, self.m.vr.frame_width], [0, self.m.vr.frame_height]
+                x_range, y_range = [0, self.m.vr.frame_height], [0, self.m.vr.frame_width]
 
             self.setImage(frame, auto_scale=True)
             self.viewBox.setRange(xRange=y_range, yRange=x_range)
@@ -594,8 +573,8 @@ class MovieView(utils.FastImageWidget):
             fly_pos = self.m.ds.body_positions.data[self.m.index_other, self.m.focal_fly, self.m.track_center_index]
         fly_pos = np.array(fly_pos).astype(np.uintp)  # in case this is a dask.array
         # makes sure crop does not exceed frame bounds
-        fly_pos[0] = np.clip(fly_pos[0], self.m.box_size, self.m.vr.frame_width - 1 - self.m.box_size)
-        fly_pos[1] = np.clip(fly_pos[1], self.m.box_size, self.m.vr.frame_height - 1 - self.m.box_size)
+        fly_pos[0] = np.clip(fly_pos[0], self.m.box_size, self.m.vr.frame_height - 1 - self.m.box_size)
+        fly_pos[1] = np.clip(fly_pos[1], self.m.box_size, self.m.vr.frame_width - 1 - self.m.box_size)
         x_range = (int(fly_pos[0] - self.m.box_size), int(fly_pos[0] + self.m.box_size))
         y_range = (int(fly_pos[1] - self.m.box_size), int(fly_pos[1] + self.m.box_size))
         # frame = frame[slice(*x_range), slice(*y_range), :]  # now crop frame around the focal fly
