@@ -4,12 +4,19 @@ import logging
 logging.getLogger().setLevel(logging.INFO)
 
 recs = {
-    'rpi9-20210409_093149': {},
-    'localhost-20210617_113024': {},
+    'rpi9-20210409_093149': {
+        'root': 'tests/data',
+    },
+    'localhost-20210617_113024': {
+        'root': 'tests/data',
+    },
     'localhost-20181120_144618': {
         'target_sampling_rate': 100,  # from default of 1_000 to speed things up
+        'root': 'tests/data',
+    },
+    'localhost-20210624_104612': {
+        'root': 'tests/data',
     },
-    'localhost-20210624_104612': {},
     'localhost-20210628_145223': {
         'dat_path': 'dat',
         'res_path': 'res',
@@ -24,15 +31,15 @@ recs = {
         'dat_path': 'dat',
         'res_path': 'dat',
         'root': 'tests/data',
-        'filepath_daq': 'dat/Dmel_male.wav',
-        'filepath_annotations': 'dat/Dmel_male_annotations.csv'
+        'filepath_daq': 'tests/data/dat/Dmel_male.wav',
+        'filepath_annotations': 'tests/data/dat/Dmel_male_annotations.csv'
     },
     'Dmel_male2': {
         'dat_path': 'dat',
         'res_path': 'dat',
         'root': 'tests/data',
-        'filepath_daq': 'dat/Dmel_male.npz',
-        'filepath_annotations': 'dat/Dmel_male_annotations.csv'
+        'filepath_daq': 'tests/data/dat/Dmel_male.npz',
+        'filepath_annotations': 'tests/data/dat/Dmel_male_annotations.csv'
     }
 }
 
